function [x,y] = FindCornerLocation_rever( lon,lat,lon_temp,lat_temp)
%
%   [x,y] = FindCornerLocation_rever( lon,lat,lon_temp,lat_temp)
%
% input the latitude and longitude of one point, this function is used to find the position
% in image according to its lat and lon matrix
% input: 
%       lon: the reference longitude matrix of image
%       lat: the reference latitude matrix of image
%       lon_temp: the longitude of point
%       lat_temp: the latitude of point
% output:
%       x: the x-coordinate of point in searching image
%       y: the y-coordinate of point in searching image
%
    bias=(lat-lat_temp).^2+(lon-lon_temp).^2;
    [minv,ind]=min(bias,[],1); 
    [~,ind2]=min(minv);
    x=ind(ind2);
    y=ind2;
end